==> client-java-api-9.0.2-sources.jar: io/kubernetes/client/openapi/models/V1beta1CertificateSigningRequestSpecFluent.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Byte;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface V1beta1CertificateSigningRequestSpecFluent<A extends V1beta1CertificateSigningRequestSpecFluent<A>> extends Fluent<A>{


    public A addToExtra(String key,List<String> value);
    public A addToExtra(Map<String,List<String>> map);
    public A removeFromExtra(String key);
    public A removeFromExtra(Map<String,List<String>> map);
    public Map<String,List<String>> getExtra();
    public A withExtra(Map<String,List<String>> extra);
    public Boolean hasExtra();
    public A addToGroups(int index,String item);
    public A setToGroups(int index,String item);
    public A addToGroups(String... items);
    public A addAllToGroups(Collection<String> items);
    public A removeFromGroups(String... items);
    public A removeAllFromGroups(Collection<String> items);
    public List<String> getGroups();
    public String getGroup(int index);
    public String getFirstGroup();
    public String getLastGroup();
    public String getMatchingGroup(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingGroup(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withGroups(List<String> groups);
    public A withGroups(String... groups);
    public Boolean hasGroups();
    public A addNewGroup(String arg1);
    public A addNewGroup(StringBuilder arg1);
    public A addNewGroup(StringBuffer arg1);
    public A withRequest(byte... request);
    public byte[] getRequest();
    public A addToRequest(int index,Byte item);
    public A setToRequest(int index,Byte item);
    public A addToRequest(Byte... items);
    public A addAllToRequest(Collection<Byte> items);
    public A removeFromRequest(Byte... items);
    public A removeAllFromRequest(Collection<Byte> items);
    public Boolean hasRequest();
    public A addNewRequest(String arg1);
    public A addNewRequest(byte arg1);
    public String getUid();
    public A withUid(String uid);
    public Boolean hasUid();
    public A withNewUid(String arg1);
    public A withNewUid(StringBuilder arg1);
    public A withNewUid(StringBuffer arg1);
    public A addToUsages(int index,String item);
    public A setToUsages(int index,String item);
    public A addToUsages(String... items);
    public A addAllToUsages(Collection<String> items);
    public A removeFromUsages(String... items);
    public A removeAllFromUsages(Collection<String> items);
    public List<String> getUsages();
    public String getUsage(int index);
    public String getFirstUsage();
    public String getLastUsage();
    public String getMatchingUsage(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingUsage(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withUsages(List<String> usages);
    public A withUsages(String... usages);
    public Boolean hasUsages();
    public A addNewUsage(String arg1);
    public A addNewUsage(StringBuilder arg1);
    public A addNewUsage(StringBuffer arg1);
    public String getUsername();
    public A withUsername(String username);
    public Boolean hasUsername();
    public A withNewUsername(String arg1);
    public A withNewUsername(StringBuilder arg1);
    public A withNewUsername(StringBuffer arg1);



}

==> client-java-api-10.0.0-sources.jar: io/kubernetes/client/openapi/models/V1beta1CertificateSigningRequestSpecFluent.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Byte;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface V1beta1CertificateSigningRequestSpecFluent<A extends V1beta1CertificateSigningRequestSpecFluent<A>> extends Fluent<A>{


    public A addToExtra(String key,List<String> value);
    public A addToExtra(Map<String,List<String>> map);
    public A removeFromExtra(String key);
    public A removeFromExtra(Map<String,List<String>> map);
    public Map<String,List<String>> getExtra();
    public A withExtra(Map<String,List<String>> extra);
    public Boolean hasExtra();
    public A addToGroups(int index,String item);
    public A setToGroups(int index,String item);
    public A addToGroups(String... items);
    public A addAllToGroups(Collection<String> items);
    public A removeFromGroups(String... items);
    public A removeAllFromGroups(Collection<String> items);
    public List<String> getGroups();
    public String getGroup(int index);
    public String getFirstGroup();
    public String getLastGroup();
    public String getMatchingGroup(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingGroup(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withGroups(List<String> groups);
    public A withGroups(String... groups);
    public Boolean hasGroups();
    public A addNewGroup(String arg1);
    public A addNewGroup(StringBuilder arg1);
    public A addNewGroup(StringBuffer arg1);
    public A withRequest(byte... request);
    public byte[] getRequest();
    public A addToRequest(int index,Byte item);
    public A setToRequest(int index,Byte item);
    public A addToRequest(Byte... items);
    public A addAllToRequest(Collection<Byte> items);
    public A removeFromRequest(Byte... items);
    public A removeAllFromRequest(Collection<Byte> items);
    public Boolean hasRequest();
    public A addNewRequest(String arg1);
    public A addNewRequest(byte arg1);
    public String getSignerName();
    public A withSignerName(String signerName);
    public Boolean hasSignerName();
    public A withNewSignerName(String arg1);
    public A withNewSignerName(StringBuilder arg1);
    public A withNewSignerName(StringBuffer arg1);
    public String getUid();
    public A withUid(String uid);
    public Boolean hasUid();
    public A withNewUid(String arg1);
    public A withNewUid(StringBuilder arg1);
    public A withNewUid(StringBuffer arg1);
    public A addToUsages(int index,String item);
    public A setToUsages(int index,String item);
    public A addToUsages(String... items);
    public A addAllToUsages(Collection<String> items);
    public A removeFromUsages(String... items);
    public A removeAllFromUsages(Collection<String> items);
    public List<String> getUsages();
    public String getUsage(int index);
    public String getFirstUsage();
    public String getLastUsage();
    public String getMatchingUsage(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingUsage(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withUsages(List<String> usages);
    public A withUsages(String... usages);
    public Boolean hasUsages();
    public A addNewUsage(String arg1);
    public A addNewUsage(StringBuilder arg1);
    public A addNewUsage(StringBuffer arg1);
    public String getUsername();
    public A withUsername(String username);
    public Boolean hasUsername();
    public A withNewUsername(String arg1);
    public A withNewUsername(StringBuilder arg1);
    public A withNewUsername(StringBuffer arg1);



}
